#!/bin/sh
# usr/opt/wrdapp/mocv32/test/test.sh -- run MOC test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          08/24/93, rsregan, modified for use with moc
#


#
# Variable definitions
# --------------------
#
  TOPDIR=..
  PROG=$TOPDIR/bin/mocv32
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROGNM=moc
  END=9
  DIVD=========================================

#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 9
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# remove old output file
#
  $CLEAN

#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    if [ $Test -eq 1 ]; then Name=rmabig; fi
    if [ $Test -eq 2 ]; then Name=big60; echo "This is a long test be patient"; fi
    if [ $Test -eq 3 ]; then Name=one-d; fi
    if [ $Test -eq 4 ]; then Name=prob2; fi
    if [ $Test -eq 5 ]; then Name=prob3_78; fi
    if [ $Test -eq 6 ]; then Name=prob3_94; fi
    if [ $Test -eq 7 ]; then Name=rma; fi
    if [ $Test -eq 8 ]; then Name=s1; fi
    if [ $Test -eq 9 ]; then Name=s2; fi
    rm -f ./go ./$Name.*
    echo $Name.dat > ./go
    cp $DATA/$Name.dat .
    $PROG < go
    Test=`expr $Test + 1`
  done
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Test"
    echo
  fi

# check output against original output in $DATA directory
  $CHECK rmabig one-d prob2 prob3_78 prob3_94 rma s1 s2 big60
